# Contains a logger used by most LORA repos.

import logging

def logger(name, level):
    """
    Returns a custom logger.

    Args:
        name: (str): Name of the logger. Should always be '__name__'.
        level (str): The level of the logger
    Return:
        logging.logger(): Custom logger obj.
    """
    log_fmt = "%(asctime)s %(name)s %(levelname)s %(message)s"
    logging.basicConfig(level=level, format=log_fmt)
    logger = logging.getLogger(name)
    logger.setLevel(level)
    return logger



import setuptools
from setuptools import find_packages

# Load the README and requirements
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name = 'LoraLogger',
    version = '0.1.0',
    description = 'Custom LORA logger.',
    long_description=long_description,
    long_description_content_type = 'text/markdown',
    url = 'https://asklora.ai',
    author = 'LORA Tech',
    author_email = 'asklora@loratechai.com',
    package_dir = {
            '': 'src'},
    packages=find_packages(where='src'),
    include_package_data=True,
    zip_safe = False
)